==> syncope-3.0.15-source-release.zip: syncope-3.0.15/client/idm/console/src/main/java/org/apache/syncope/client/console/wizards/any/Resources.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.syncope.client.console.wizards.any;

import org.apache.syncope.client.console.SyncopeWebApplication;
import org.apache.syncope.client.ui.commons.wizards.any.AbstractResources;
import org.apache.syncope.client.ui.commons.wizards.any.AnyWrapper;
import org.apache.syncope.common.lib.to.AnyTO;
import org.apache.syncope.common.lib.types.IdMEntitlement;
import org.apache.wicket.authroles.authorization.strategies.role.metadata.ActionPermissions;
import org.apache.wicket.authroles.authorization.strategies.role.metadata.MetaDataRoleAuthorizationStrategy;

public class Resources extends AbstractResources {

    private static final long serialVersionUID = 702900610508752856L;

    public <T extends AnyTO> Resources(final AnyWrapper<T> modelObject) {
        super(modelObject);

        // -----------------------------------------------------------------
        // Pre-Authorizations
        // -----------------------------------------------------------------
        final ActionPermissions permissions = new ActionPermissions();
        setMetaData(MetaDataRoleAuthorizationStrategy.ACTION_PERMISSIONS, permissions);
        permissions.authorize(RENDER,
                new org.apache.wicket.authroles.authorization.strategies.role.Roles(IdMEntitlement.RESOURCE_LIST));
        // -----------------------------------------------------------------
    }

    @Override
    public boolean evaluate() {
        if (SyncopeWebApplication.get().getSecuritySettings().
                getAuthorizationStrategy().isActionAuthorized(this, RENDER)) {

            available.setObject(SyncopeWebApplication.get().getResourceProvider().get(anyTO.getType()));
            return !available.getObject().isEmpty();
        }
        return false;
    }
}

==> syncope-4.0.1-source-release.zip: syncope-4.0.1/client/idm/console/src/main/java/org/apache/syncope/client/console/wizards/any/Resources.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.syncope.client.console.wizards.any;

import org.apache.syncope.client.console.SyncopeWebApplication;
import org.apache.syncope.client.ui.commons.wizards.any.AbstractResources;
import org.apache.syncope.client.ui.commons.wizards.any.AnyWrapper;
import org.apache.syncope.common.lib.to.AnyTO;
import org.apache.syncope.common.lib.types.IdMEntitlement;
import org.apache.wicket.authroles.authorization.strategies.role.metadata.ActionPermissions;
import org.apache.wicket.authroles.authorization.strategies.role.metadata.MetaDataRoleAuthorizationStrategy;

public class Resources extends AbstractResources {

    private static final long serialVersionUID = 702900610508752856L;

    public <T extends AnyTO> Resources(final AnyWrapper<T> modelObject) {
        super(modelObject);

        // -----------------------------------------------------------------
        // Pre-Authorizations
        // -----------------------------------------------------------------
        final ActionPermissions permissions = new ActionPermissions();
        setMetaData(MetaDataRoleAuthorizationStrategy.ACTION_PERMISSIONS, permissions);
        permissions.authorize(RENDER,
                new org.apache.wicket.authroles.authorization.strategies.role.Roles(IdMEntitlement.RESOURCE_LIST));
        // -----------------------------------------------------------------
    }

    @Override
    public boolean evaluate() {
        if (SyncopeWebApplication.get().getSecuritySettings().
                getAuthorizationStrategy().isActionAuthorized(this, RENDER)) {
            available.setObject(SyncopeWebApplication.get().getResourceProvider().get());
            return !available.getObject().isEmpty();
        } else {
            return false;
        }
    }
}
